"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
const core_1 = require('@angular/core');
const http_1 = require("@angular/http");
let HttpLocalAuthService = class HttpLocalAuthService {
    constructor(http) {
        this.http = http;
        this.customHeaders = {};
        this.http = http;
    }
    /**
     * Wraps GET method
     * @param {string} url - The endpoint URL to be fetched.
     * @returns Observable
     */
    get(url) {
        return this._request(url, http_1.RequestMethod.Get, null);
    }
    /**
     * Wraps POST method
     * @param {string} url - The endpoint URL to be fetched.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    post(url, body) {
        return this._request(url, http_1.RequestMethod.Post, body);
    }
    /**
     * Wraps PUT method
     * @param {string} url - The endpoint URL to be fetched.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    put(url, body) {
        return this._request(url, http_1.RequestMethod.Put, body);
    }
    /**
     * Wraps PATCH method
     * @param {string} url - The endpoint URL to be fetched.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    patch(url, body) {
        return this._request(url, http_1.RequestMethod.Patch, body);
    }
    /**
     * Wraps DELETE method
     * @param {string} url - The endpoint URL to be fetched.
     * @returns Observable
     */
    delete(url) {
        return this._request(url, http_1.RequestMethod.Delete, null);
    }
    /**
     * Appends headers for the next request
     * @param {Object} headerObject - Collection of headers to be appended.
     */
    addHeaders(headerObject) {
        this.customHeaders = headerObject;
    }
    /**
     * Appends headers for the next request
     * @param {string} url - The endpoint URL to be fetched.
     * @param {RequestMethod} method - HTTP Verb method to be used.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    _request(url, method, body) {
        let headers = new http_1.Headers({ 'Accept': 'application/json', 'Content-Type': 'application/json' });
        this.createAuthorizationHeader(headers);
        this.appendCreatedHeaders(headers);
        let options = new http_1.BaseRequestOptions();
        options.headers = headers;
        options.url = url;
        options.method = method;
        options.body = body;
        options.withCredentials = true;
        let request = new http_1.Request(options);
        return this.http.request(request);
    }
    /**
     * Creates Authorization header to be used globally
     * @param {Headers} headers - Current Header data.
     */
    createAuthorizationHeader(headers) {
        if (localStorage.getItem("token") !== null) {
            headers.append('Authorization', `Bearer ${localStorage.getItem("token")}`);
        }
    }
    /**
     * Appends custom headers defined before each request
     * @param {Headers} headers - Current Header data.
     */
    appendCreatedHeaders(headers) {
        let createdHeaders = this.customHeaders;
        if (Object.keys(createdHeaders).length > 0) {
            for (let key in createdHeaders) {
                headers.append(key, createdHeaders[key]);
            }
            this.customHeaders = [];
        }
    }
};
HttpLocalAuthService = __decorate([
    core_1.Injectable(), 
    __metadata('design:paramtypes', [http_1.Http])
], HttpLocalAuthService);
exports.HttpLocalAuthService = HttpLocalAuthService;
//# sourceMappingURL=http-local-auth.service.js.map